==> humhub-1.12.0.tar.gz: humhub-1.12.0/protected/humhub/modules/space/messages/hr/base.php <==
<?php

return [
    '<b>This space is still empty!</b>' => '<b>Ovaj prostor je još prazan!</b>',
    '<b>This space is still empty!</b><br>Start by posting something here...' => '<b>Ovaj prostor je još prazan!</b><br>Počnite s objavljivanjem nečega...',
    '<b>You are not member of this space and there is no public content, yet!</b>' => '<b>Niste član ovog prostora i još uvijek nema javnog sadržaja!</b>',
    '<strong>About</strong> the Space' => '<strong> O</strong> prostoru',
    '<strong>About</strong> your membership' => '<strong>O</strong> vašem članstvu',
    '<strong>Confirm</strong> image deletion' => '<strong>Potvrdi</strong> brisanje slike',
    '<strong>Invite</strong> members' => '<strong>Pozovite</strong> članove',
    '<strong>New</strong> member request' => '<strong>Novi</strong> zahtjev za članstvom',
    '<strong>New</strong> spaces' => '<strong>Novi</strong> prostori',
    '<strong>Request</strong> Membership' => '<strong>Zahtjev</strong> za članstvom u prostoru',
    '<strong>Space</strong> followers' => '<strong> Prostor</strong> - pratitelji',
    '<strong>Space</strong> members' => '<strong>Članovi</strong> prostora',
    '<strong>Space</strong> menu' => '<strong>Prostorni</strong> izbornik',
    'About' => 'O meni',
    'Accept' => 'Prihvati',
    'Accept Invite' => 'Prihvati poziv',
    'Access to this Space is restricted. Please introduce yourself to become a member.' => 'Ukratko se predstavite i postanite odobreni član tog prostora.',
    'Add users without invitation' => 'Dodajte korisnike bez pozivnice',
    'Admin' => 'Admin',
    'Administrator:' => 'Administrator:',
    'Administrators' => 'Administratori',
    'Archived' => 'Arhivirano',
    'As owner you cannot revoke your membership!' => 'Kao vlasnik ne možete opozvati vaše članstvo!',
    'Cancel' => 'Poništi',
    'Close' => 'Zatvori',
    'Color' => 'Boja',
    'Could not request membership!' => 'Nije bilo moguće tražiti članstvo!',
    'Created At' => 'Kreirano u',
    'Created By' => 'Kreirano od',
    'Decline' => 'Odbij',
    'Decline Invite' => 'Odbij poziv',
    'Default' => 'Zadano',
    'Default content visibility' => 'Zadana vidljivost sadržaja',
    'Delete' => 'Obriši.',
    'Description' => 'Opis',
    'Do you really want to delete your profile image?' => 'Zaista želite obrisati vašu profilnu sliku?',
    'Do you really want to delete your title image?' => 'Zaista želite obrisati naslovnu sliku?',
    'Done' => 'Učinjeno',
    'Email addresses' => 'Email adrese',
    'Everyone can enter' => 'Svi mogu ući',
    'Follow' => 'Prati',
    'Followers' => 'Pratitelji',
    'Following' => 'Prati',
    'Homepage' => 'Početna stranica',
    'Homepage (Guests)' => 'Početna stranica (Gosti)',
    'Invite' => 'Poziv',
    'Invite and request' => 'Poziv i zahtjev',
    'Invite by email' => 'Poziv email-om',
    'Invites' => 'Pozivi',
    'Join Policy' => 'Pravilo pridruživanja',
    'Last Visit' => 'Zadnji posjet',
    'Login' => 'Prijava',
    'Max. 100 characters.' => 'Maks. 100 znakova.',
    'Member since' => 'Član od',
    'Members' => 'Članovi',
    'Moderator' => 'Moderator',
    'Moderator:' => 'Moderator:',
    'Moderators' => 'Moderatori',
    'My Space List' => 'Moj popis prostora',
    'My space summary' => 'Moji sažeci prostora',
    'Name' => 'Ime',
    'New user by e-mail (comma separated)' => 'Novi korisnik preko e-mail (odvojeno zarezom)',
    'New user?' => 'Novi korisnik?',
    'No spaces found.' => 'Nisu pronađeni prostori.',
    'Only by invite' => 'Samo pozivom',
    'Originator User ID' => 'Korisnički ID začetnika',
    'Owner' => 'Vlasnik',
    'Owner:' => 'Vlasnik:',
    'Pick users' => 'Odaberi korisnike',
    'Posts' => 'Objave',
    'Private' => 'Privatno',
    'Private (Invisible)' => 'Privatno (Nevidljivo)',
    'Public' => 'Javno',
    'Public (Members & Guests)' => 'Javno (Članovi i gosti)',
    'Public (Members only)' => 'Javno (Samo članovi)',
    'Public (Registered users only)' => 'Javno (Samo registrirani korisnici)',
    'Request Message' => 'Zatražite poruku',
    'Role' => 'Uloga',
    'See all' => 'Vidi sve',
    'Select all registered users' => 'Odaberite sve registrirane korisnike',
    'Send' => 'Pošalji',
    'Settings' => 'Postavke',
    'Settings could not be saved!' => 'Postavke nije moguće spremiti!',
    'Show all' => 'Prikaži sve',
    'Shown on About Page.' => 'Prikazano na stranici O prostoru',
    'Sorry, you are not allowed to leave this space!' => 'Žao nam je, ne smijete napustiti ovaj prostor!',
    'Sorting' => 'Sortiranje',
    'Space' => 'Prostor',
    'Space Visibility' => 'Vidljivost prostora',
    'Space directory' => 'Direktorij prostora',
    'Space is invisible!' => 'Prostor je nevidljiv!',
    'Spaces' => 'Prostori',
    'Status' => 'Status',
    'Stream' => 'Stream',
    'Tags' => 'Tag-ovi',
    'There is no pending invite!' => 'Nema pozivnice na čekanju!',
    'This action is only available for workspace members!' => 'Ova je akcija dostupna samo za članove radnog prostora!',
    'This user is already a member of this space.' => 'Ovaj je korisnik već član tog prostora.',
    'This user is not a member of this space.' => 'Ovaj korisnik nije član tog prostora.',
    'To invite users to this space, please type their names below to find and pick them.' => 'Kako biste pozvali korisnike na ovaj prostor, upišite njihova imena u nastavku da biste ih pronašli i odabrali.',
    'Updated At' => 'Ažurirano u',
    'Updated By' => 'Ažurirano od',
    'Updated by' => 'Ažurirano od',
    'User \'{username}\' is already a member of this space!' => 'Korisnik \'{username}\' je već član ovog prostora!',
    'User invitations have been added to the queue' => 'Korisničke pozivnice dodane su u red čekanja',
    'User memberships have been added to the queue' => 'Članstva korisnika dodana su u red čekanja',
    'User not found!' => 'Korisnik nije pronađen!',
    'Users' => 'Korisnici',
    'Users has been invited.' => 'Korisnici su pozvani.',
    'Visibility' => 'Vidljivost',
    'Visible for all (members and guests)' => 'Vidljivo za sve (članovi i gosti)',
    'You are not allowed to join this space!' => 'Ne smijete se pridružiti ovom prostoru!',
    'You can also invite external users, which are not registered now. Just add their e-mail addresses separated by comma.' => 'Možete pozvati i vanjske korisnike, koji sada nisu registrirani. Dovoljno je dodati njihove adrese e-pošte odvojene zarezom.',
    'You cannot create private visible spaces!' => 'Ne možete stvoriti privatne vidljive prostore!',
    'You cannot create public visible spaces!' => 'Ne možete stvoriti javne vidljive prostore!',
    'You need to login to view contents of this space!' => 'Morate se prijaviti da vidite sadržaj prostora!',
    'Your Message' => 'Poruka prijave',
    'Your request was successfully submitted to the space administrators.' => 'Vaš je zahtjev uspješno poslan administratorima prostora.',
    '{count} members' => '{count} članova',
    '{email} is not valid!' => '{email} nije važeći!',
    '<strong>Space</strong> tags' => '',
    '<strong>Spaces</strong>' => '',
    'Any' => '',
    'Blocked users' => '',
    'By Name' => '',
    'Find Spaces by their description or by their tags' => '',
    'Guests' => '',
    'Hide Members sidebar in the stream page.' => '',
    'I want to become a member because...' => '',
    'Join' => '',
    'Member' => '',
    'Neither..nor' => '',
    'Newest first' => '',
    'No results found!' => '',
    'Oldest first' => '',
    'Pending' => '',
    'Search...' => '',
    'Try other keywords or remove filters.' => '',
    'Would you like to end your membership in Space {spaceName}?' => '',
    'Would you like to unfollow Space {spaceName}?' => '',
    'Would you like to unfollow {userName}?' => '',
    'Would you like to withdraw your request to join Space {spaceName}?' => '',
];

==> humhub-1.13.1.tar.gz: humhub-1.13.1/protected/humhub/modules/space/messages/hr/base.php <==
<?php

return [
    '<b>This space is still empty!</b>' => '<b>Ovaj prostor je još prazan!</b>',
    '<b>This space is still empty!</b><br>Start by posting something here...' => '<b>Ovaj prostor je još prazan!</b><br>Počnite s objavljivanjem nečega...',
    '<b>You are not member of this space and there is no public content, yet!</b>' => '<b>Niste član ovog prostora i još uvijek nema javnog sadržaja!</b>',
    '<strong>About</strong> the Space' => '<strong> O</strong> prostoru',
    '<strong>About</strong> your membership' => '<strong>O</strong> vašem članstvu',
    '<strong>Confirm</strong> image deletion' => '<strong>Potvrdi</strong> brisanje slike',
    '<strong>Invite</strong> members' => '<strong>Pozovite</strong> članove',
    '<strong>New</strong> member request' => '<strong>Novi</strong> zahtjev za članstvom',
    '<strong>New</strong> spaces' => '<strong>Novi</strong> prostori',
    '<strong>Request</strong> Membership' => '<strong>Zahtjev</strong> za članstvom u prostoru',
    '<strong>Space</strong> followers' => '<strong> Prostor</strong> - pratitelji',
    '<strong>Space</strong> members' => '<strong>Članovi</strong> prostora',
    '<strong>Space</strong> menu' => '<strong>Prostorni</strong> izbornik',
    'About' => 'O meni',
    'Accept' => 'Prihvati',
    'Accept Invite' => 'Prihvati poziv',
    'Access to this Space is restricted. Please introduce yourself to become a member.' => 'Ukratko se predstavite i postanite odobreni član tog prostora.',
    'Add users without invitation' => 'Dodajte korisnike bez pozivnice',
    'Admin' => 'Admin',
    'Administrator:' => 'Administrator:',
    'Administrators' => 'Administratori',
    'Archived' => 'Arhivirano',
    'As owner you cannot revoke your membership!' => 'Kao vlasnik ne možete opozvati vaše članstvo!',
    'Cancel' => 'Poništi',
    'Close' => 'Zatvori',
    'Color' => 'Boja',
    'Could not request membership!' => 'Nije bilo moguće tražiti članstvo!',
    'Created At' => 'Kreirano u',
    'Created By' => 'Kreirano od',
    'Decline' => 'Odbij',
    'Decline Invite' => 'Odbij poziv',
    'Default' => 'Zadano',
    'Default content visibility' => 'Zadana vidljivost sadržaja',
    'Delete' => 'Obriši.',
    'Description' => 'Opis',
    'Do you really want to delete your profile image?' => 'Zaista želite obrisati vašu profilnu sliku?',
    'Do you really want to delete your title image?' => 'Zaista želite obrisati naslovnu sliku?',
    'Done' => 'Učinjeno',
    'Email addresses' => 'Email adrese',
    'Everyone can enter' => 'Svi mogu ući',
    'Follow' => 'Prati',
    'Followers' => 'Pratitelji',
    'Following' => 'Prati',
    'Homepage' => 'Početna stranica',
    'Invite' => 'Poziv',
    'Invite and request' => 'Poziv i zahtjev',
    'Invite by email' => 'Poziv email-om',
    'Invites' => 'Pozivi',
    'Join Policy' => 'Pravilo pridruživanja',
    'Last Visit' => 'Zadnji posjet',
    'Login' => 'Prijava',
    'Max. 100 characters.' => 'Maks. 100 znakova.',
    'Member since' => 'Član od',
    'Members' => 'Članovi',
    'Moderator' => 'Moderator',
    'Moderator:' => 'Moderator:',
    'Moderators' => 'Moderatori',
    'My Space List' => 'Moj popis prostora',
    'My space summary' => 'Moji sažeci prostora',
    'Name' => 'Ime',
    'New user by e-mail (comma separated)' => 'Novi korisnik preko e-mail (odvojeno zarezom)',
    'New user?' => 'Novi korisnik?',
    'No spaces found.' => 'Nisu pronađeni prostori.',
    'Only by invite' => 'Samo pozivom',
    'Originator User ID' => 'Korisnički ID začetnika',
    'Owner' => 'Vlasnik',
    'Owner:' => 'Vlasnik:',
    'Pick users' => 'Odaberi korisnike',
    'Posts' => 'Objave',
    'Private' => 'Privatno',
    'Private (Invisible)' => 'Privatno (Nevidljivo)',
    'Public' => 'Javno',
    'Public (Members & Guests)' => 'Javno (Članovi i gosti)',
    'Public (Members only)' => 'Javno (Samo članovi)',
    'Public (Registered users only)' => 'Javno (Samo registrirani korisnici)',
    'Request Message' => 'Zatražite poruku',
    'Role' => 'Uloga',
    'See all' => 'Vidi sve',
    'Select all registered users' => 'Odaberite sve registrirane korisnike',
    'Send' => 'Pošalji',
    'Settings' => 'Postavke',
    'Settings could not be saved!' => 'Postavke nije moguće spremiti!',
    'Show all' => 'Prikaži sve',
    'Shown on About Page.' => 'Prikazano na stranici O prostoru',
    'Sorry, you are not allowed to leave this space!' => 'Žao nam je, ne smijete napustiti ovaj prostor!',
    'Sorting' => 'Sortiranje',
    'Space' => 'Prostor',
    'Space Visibility' => 'Vidljivost prostora',
    'Space directory' => 'Direktorij prostora',
    'Space is invisible!' => 'Prostor je nevidljiv!',
    'Spaces' => 'Prostori',
    'Status' => 'Status',
    'Stream' => 'Stream',
    'Tags' => 'Tag-ovi',
    'There is no pending invite!' => 'Nema pozivnice na čekanju!',
    'This action is only available for workspace members!' => 'Ova je akcija dostupna samo za članove radnog prostora!',
    'This user is already a member of this space.' => 'Ovaj je korisnik već član tog prostora.',
    'This user is not a member of this space.' => 'Ovaj korisnik nije član tog prostora.',
    'To invite users to this space, please type their names below to find and pick them.' => 'Kako biste pozvali korisnike na ovaj prostor, upišite njihova imena u nastavku da biste ih pronašli i odabrali.',
    'Updated At' => 'Ažurirano u',
    'Updated By' => 'Ažurirano od',
    'Updated by' => 'Ažurirano od',
    'User \'{username}\' is already a member of this space!' => 'Korisnik \'{username}\' je već član ovog prostora!',
    'User invitations have been added to the queue' => 'Korisničke pozivnice dodane su u red čekanja',
    'User memberships have been added to the queue' => 'Članstva korisnika dodana su u red čekanja',
    'User not found!' => 'Korisnik nije pronađen!',
    'Users' => 'Korisnici',
    'Users has been invited.' => 'Korisnici su pozvani.',
    'Visibility' => 'Vidljivost',
    'Visible for all (members and guests)' => 'Vidljivo za sve (članovi i gosti)',
    'You are not allowed to join this space!' => 'Ne smijete se pridružiti ovom prostoru!',
    'You can also invite external users, which are not registered now. Just add their e-mail addresses separated by comma.' => 'Možete pozvati i vanjske korisnike, koji sada nisu registrirani. Dovoljno je dodati njihove adrese e-pošte odvojene zarezom.',
    'You cannot create private visible spaces!' => 'Ne možete stvoriti privatne vidljive prostore!',
    'You cannot create public visible spaces!' => 'Ne možete stvoriti javne vidljive prostore!',
    'You need to login to view contents of this space!' => 'Morate se prijaviti da vidite sadržaj prostora!',
    'Your Message' => 'Poruka prijave',
    'Your request was successfully submitted to the space administrators.' => 'Vaš je zahtjev uspješno poslan administratorima prostora.',
    '{count} members' => '{count} članova',
    '{email} is not valid!' => '{email} nije važeći!',
    '<strong>Space</strong> tags' => '',
    '<strong>Spaces</strong>' => '',
    'Any' => '',
    'Blocked users' => '',
    'By Name' => '',
    'Find Spaces by their description or by their tags' => '',
    'Guests' => '',
    'Hide About Page' => '',
    'Hide Activity Sidebar Widget' => '',
    'Hide Followers' => '',
    'Hide Members' => '',
    'Homepage (Guests)' => '',
    'I want to become a member because...' => '',
    'Join' => '',
    'Member' => '',
    'Neither..nor' => '',
    'Newest first' => '',
    'No results found!' => '',
    'Oldest first' => '',
    'Pending' => '',
    'Search...' => '',
    'Show as List' => '',
    'Try other keywords or remove filters.' => '',
    'Would you like to end your membership in Space {spaceName}?' => '',
    'Would you like to unfollow Space {spaceName}?' => '',
    'Would you like to unfollow {userName}?' => '',
    'Would you like to withdraw your request to join Space {spaceName}?' => '',
];
